package com.pichillilorenzo.flutter_inappwebview.types;

import X.l;
import android.text.TextUtils;
import com.pichillilorenzo.flutter_inappwebview.Util;
import com.pichillilorenzo.flutter_inappwebview.plugin_scripts_js.PluginScriptsUtil;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.json.JSONObject;
/* loaded from: classes.dex */
public class UserContentController {
    private static final String CONTENT_WORLDS_GENERATOR_JS_SOURCE = "(function() {  var contentWorldNames = [$IN_APP_WEBVIEW_CONTENT_WORLD_NAME_ARRAY];  for (var contentWorldName of contentWorldNames) {    var iframeId = 'flutter_inappwebview_' + contentWorldName;    var iframe = document.getElementById(iframeId);    if (iframe == null) {      iframe = document.createElement('iframe');      iframe.id = iframeId;      iframe.style = 'display: none; z-index: 0; position: absolute; width: 0px; height: 0px';      document.body.append(iframe);    }    var script = iframe.contentWindow.document.createElement('script');    script.innerHTML = $IN_APP_WEBVIEW_JSON_SOURCE_ENCODED;    iframe.contentWindow.document.body.append(script);  }})();";
    private static final String CONTENT_WORLD_WRAPPER_JS_SOURCE = "(function() {  var iframeId = 'flutter_inappwebview_$IN_APP_WEBVIEW_CONTENT_WORLD_NAME';  var iframe = document.getElementById(iframeId);  if (iframe == null) {    iframe = document.createElement('iframe');    iframe.id = iframeId;    iframe.style = 'display: none; z-index: 0; position: absolute; width: 0px; height: 0px';    document.body.append(iframe);  }  var script = iframe.contentWindow.document.createElement('script');  script.innerHTML = $IN_APP_WEBVIEW_JSON_SOURCE_ENCODED;  iframe.contentWindow.document.body.append(script);})();";
    private static final String DOCUMENT_READY_WRAPPER_JS_SOURCE = "if (document.readyState === 'interactive' || document.readyState === 'complete') {   $IN_APP_WEBVIEW_PLACEHOLDER_VALUE}";
    protected static final String LOG_TAG = "UserContentController";
    private static final String USER_SCRIPTS_AT_DOCUMENT_END_WRAPPER_JS_SOURCE = "if (window.flutter_inappwebview != null && (window.flutter_inappwebview._userScriptsAtDocumentEndLoaded == null || !window.flutter_inappwebview._userScriptsAtDocumentEndLoaded)) {  window.flutter_inappwebview._userScriptsAtDocumentEndLoaded = true;  $IN_APP_WEBVIEW_PLACEHOLDER_VALUE}";
    private static final String USER_SCRIPTS_AT_DOCUMENT_START_WRAPPER_JS_SOURCE = "if (window.flutter_inappwebview != null && (window.flutter_inappwebview._userScriptsAtDocumentStartLoaded == null || !window.flutter_inappwebview._userScriptsAtDocumentStartLoaded)) {  window.flutter_inappwebview._userScriptsAtDocumentStartLoaded = true;  $IN_APP_WEBVIEW_PLACEHOLDER_VALUE}";
    private final Set contentWorlds = new HashSet() { // from class: com.pichillilorenzo.flutter_inappwebview.types.UserContentController.1
        {
            add(ContentWorld.PAGE);
        }
    };
    private final Map userOnlyScripts = new HashMap() { // from class: com.pichillilorenzo.flutter_inappwebview.types.UserContentController.2
        {
            put(UserScriptInjectionTime.AT_DOCUMENT_START, new LinkedHashSet());
            put(UserScriptInjectionTime.AT_DOCUMENT_END, new LinkedHashSet());
        }
    };
    private final Map pluginScripts = new HashMap() { // from class: com.pichillilorenzo.flutter_inappwebview.types.UserContentController.3
        {
            put(UserScriptInjectionTime.AT_DOCUMENT_START, new LinkedHashSet());
            put(UserScriptInjectionTime.AT_DOCUMENT_END, new LinkedHashSet());
        }
    };

    public static String escapeCode(String str) {
        return JSONObject.quote(str);
    }

    public static String escapeContentWorldName(String str) {
        return str.replaceAll("'", "\\\\'");
    }

    public boolean addPluginScript(PluginScript pluginScript) {
        ContentWorld contentWorld = pluginScript.getContentWorld();
        if (contentWorld != null) {
            this.contentWorlds.add(contentWorld);
        }
        return ((LinkedHashSet) this.pluginScripts.get(pluginScript.getInjectionTime())).add(pluginScript);
    }

    public void addPluginScripts(List list) {
        Iterator it = list.iterator();
        while (it.hasNext()) {
            addPluginScript((PluginScript) it.next());
        }
    }

    public boolean addUserOnlyScript(UserScript userScript) {
        ContentWorld contentWorld = userScript.getContentWorld();
        if (contentWorld != null) {
            this.contentWorlds.add(contentWorld);
        }
        return ((LinkedHashSet) this.userOnlyScripts.get(userScript.getInjectionTime())).add(userScript);
    }

    public void addUserOnlyScripts(List list) {
        Iterator it = list.iterator();
        while (it.hasNext()) {
            addUserOnlyScript((UserScript) it.next());
        }
    }

    public boolean containsPluginScript(PluginScript pluginScript) {
        return getPluginScriptAsList().contains(pluginScript);
    }

    public boolean containsPluginScriptByGroupName(String str) {
        Iterator it = getPluginScriptAsList().iterator();
        while (it.hasNext()) {
            if (Util.objEquals(str, ((PluginScript) it.next()).getGroupName())) {
                return true;
            }
        }
        return false;
    }

    public boolean containsUserOnlyScript(UserScript userScript) {
        return getUserOnlyScriptAsList().contains(userScript);
    }

    public boolean containsUserOnlyScriptByGroupName(String str) {
        Iterator it = getUserOnlyScriptAsList().iterator();
        while (it.hasNext()) {
            if (Util.objEquals(str, ((UserScript) it.next()).getGroupName())) {
                return true;
            }
        }
        return false;
    }

    public String generateCodeForDocumentStart() {
        UserScriptInjectionTime userScriptInjectionTime = UserScriptInjectionTime.AT_DOCUMENT_START;
        StringBuilder y2 = l.y("");
        y2.append(generatePluginScriptsCodeAt(userScriptInjectionTime));
        StringBuilder y3 = l.y(y2.toString());
        y3.append(generateContentWorldsCreatorCode());
        StringBuilder y4 = l.y(y3.toString());
        y4.append(generateUserOnlyScriptsCodeAt(userScriptInjectionTime));
        return USER_SCRIPTS_AT_DOCUMENT_START_WRAPPER_JS_SOURCE.replace(PluginScriptsUtil.VAR_PLACEHOLDER_VALUE, y4.toString());
    }

    public String generateCodeForScriptEvaluation(String str, ContentWorld contentWorld) {
        if (contentWorld == null || contentWorld.equals(ContentWorld.PAGE)) {
            return str;
        }
        StringBuilder sb = new StringBuilder();
        if (!this.contentWorlds.contains(contentWorld)) {
            this.contentWorlds.add(contentWorld);
            Iterator it = getPluginScriptsRequiredInAllContentWorlds().iterator();
            while (it.hasNext()) {
                sb.append(";");
                sb.append(((PluginScript) it.next()).getSource());
            }
        }
        sb.append(str);
        return wrapSourceCodeInContentWorld(contentWorld, sb.toString());
    }

    public String generateContentWorldsCreatorCode() {
        if (this.contentWorlds.size() == 1) {
            return "";
        }
        StringBuilder sb = new StringBuilder();
        Iterator it = getPluginScriptsRequiredInAllContentWorlds().iterator();
        while (it.hasNext()) {
            sb.append(((PluginScript) it.next()).getSource());
        }
        ArrayList arrayList = new ArrayList();
        for (ContentWorld contentWorld : this.contentWorlds) {
            if (!contentWorld.equals(ContentWorld.PAGE)) {
                StringBuilder y2 = l.y("'");
                y2.append(escapeContentWorldName(contentWorld.getName()));
                y2.append("'");
                arrayList.add(y2.toString());
            }
        }
        return CONTENT_WORLDS_GENERATOR_JS_SOURCE.replace(PluginScriptsUtil.VAR_CONTENT_WORLD_NAME_ARRAY, TextUtils.join(", ", arrayList)).replace(PluginScriptsUtil.VAR_JSON_SOURCE_ENCODED, escapeCode(sb.toString()));
    }

    public String generatePluginScriptsCodeAt(UserScriptInjectionTime userScriptInjectionTime) {
        StringBuilder sb = new StringBuilder();
        Iterator it = getPluginScriptsAt(userScriptInjectionTime).iterator();
        while (it.hasNext()) {
            PluginScript pluginScript = (PluginScript) it.next();
            StringBuilder y2 = l.y(";");
            y2.append(pluginScript.getSource());
            sb.append(wrapSourceCodeInContentWorld(pluginScript.getContentWorld(), y2.toString()));
        }
        return sb.toString();
    }

    public String generateUserOnlyScriptsCodeAt(UserScriptInjectionTime userScriptInjectionTime) {
        StringBuilder sb = new StringBuilder();
        Iterator it = getUserOnlyScriptsAt(userScriptInjectionTime).iterator();
        while (it.hasNext()) {
            UserScript userScript = (UserScript) it.next();
            StringBuilder y2 = l.y(";");
            y2.append(userScript.getSource());
            sb.append(wrapSourceCodeInContentWorld(userScript.getContentWorld(), y2.toString()));
        }
        return sb.toString();
    }

    public String generateWrappedCodeForDocumentEnd() {
        UserScriptInjectionTime userScriptInjectionTime = UserScriptInjectionTime.AT_DOCUMENT_END;
        StringBuilder y2 = l.y(generateCodeForDocumentStart());
        y2.append(generatePluginScriptsCodeAt(userScriptInjectionTime));
        StringBuilder y3 = l.y(y2.toString());
        y3.append(generateUserOnlyScriptsCodeAt(userScriptInjectionTime));
        return USER_SCRIPTS_AT_DOCUMENT_END_WRAPPER_JS_SOURCE.replace(PluginScriptsUtil.VAR_PLACEHOLDER_VALUE, y3.toString());
    }

    public String generateWrappedCodeForDocumentStart() {
        return Util.replaceAll(DOCUMENT_READY_WRAPPER_JS_SOURCE, PluginScriptsUtil.VAR_PLACEHOLDER_VALUE, generateCodeForDocumentStart());
    }

    public LinkedHashSet getContentWorlds() {
        return new LinkedHashSet(this.contentWorlds);
    }

    public LinkedHashSet getPluginScriptAsList() {
        LinkedHashSet linkedHashSet = new LinkedHashSet();
        for (LinkedHashSet linkedHashSet2 : this.pluginScripts.values()) {
            linkedHashSet.addAll(linkedHashSet2);
        }
        return linkedHashSet;
    }

    public LinkedHashSet getPluginScriptsAt(UserScriptInjectionTime userScriptInjectionTime) {
        return new LinkedHashSet((Collection) this.pluginScripts.get(userScriptInjectionTime));
    }

    public LinkedHashSet getPluginScriptsRequiredInAllContentWorlds() {
        LinkedHashSet linkedHashSet = new LinkedHashSet();
        Iterator it = getPluginScriptsAt(UserScriptInjectionTime.AT_DOCUMENT_START).iterator();
        while (it.hasNext()) {
            PluginScript pluginScript = (PluginScript) it.next();
            if (pluginScript.isRequiredInAllContentWorlds()) {
                linkedHashSet.add(pluginScript);
            }
        }
        return linkedHashSet;
    }

    public LinkedHashSet getUserOnlyScriptAsList() {
        LinkedHashSet linkedHashSet = new LinkedHashSet();
        for (LinkedHashSet linkedHashSet2 : this.userOnlyScripts.values()) {
            linkedHashSet.addAll(linkedHashSet2);
        }
        return linkedHashSet;
    }

    public LinkedHashSet getUserOnlyScriptsAt(UserScriptInjectionTime userScriptInjectionTime) {
        return new LinkedHashSet((Collection) this.userOnlyScripts.get(userScriptInjectionTime));
    }

    public void removeAllPluginScripts() {
        ((LinkedHashSet) this.pluginScripts.get(UserScriptInjectionTime.AT_DOCUMENT_START)).clear();
        ((LinkedHashSet) this.pluginScripts.get(UserScriptInjectionTime.AT_DOCUMENT_END)).clear();
    }

    public void removeAllUserOnlyScripts() {
        ((LinkedHashSet) this.userOnlyScripts.get(UserScriptInjectionTime.AT_DOCUMENT_START)).clear();
        ((LinkedHashSet) this.userOnlyScripts.get(UserScriptInjectionTime.AT_DOCUMENT_END)).clear();
    }

    public boolean removePluginScript(PluginScript pluginScript) {
        return ((LinkedHashSet) this.pluginScripts.get(pluginScript.getInjectionTime())).remove(pluginScript);
    }

    public void removePluginScriptsByGroupName(String str) {
        Iterator it = getPluginScriptAsList().iterator();
        while (it.hasNext()) {
            PluginScript pluginScript = (PluginScript) it.next();
            if (Util.objEquals(str, pluginScript.getGroupName())) {
                removePluginScript(pluginScript);
            }
        }
    }

    public boolean removeUserOnlyScript(UserScript userScript) {
        return ((LinkedHashSet) this.userOnlyScripts.get(userScript.getInjectionTime())).remove(userScript);
    }

    public boolean removeUserOnlyScriptAt(int i2, UserScriptInjectionTime userScriptInjectionTime) {
        return removeUserOnlyScript((UserScript) new ArrayList((Collection) this.userOnlyScripts.get(userScriptInjectionTime)).get(i2));
    }

    public void removeUserOnlyScriptsByGroupName(String str) {
        Iterator it = getUserOnlyScriptAsList().iterator();
        while (it.hasNext()) {
            UserScript userScript = (UserScript) it.next();
            if (Util.objEquals(str, userScript.getGroupName())) {
                removeUserOnlyScript(userScript);
            }
        }
    }

    public void resetContentWorlds() {
        this.contentWorlds.clear();
        this.contentWorlds.add(ContentWorld.PAGE);
        Iterator it = getPluginScriptAsList().iterator();
        while (it.hasNext()) {
            this.contentWorlds.add(((PluginScript) it.next()).getContentWorld());
        }
        Iterator it2 = getUserOnlyScriptAsList().iterator();
        while (it2.hasNext()) {
            this.contentWorlds.add(((UserScript) it2.next()).getContentWorld());
        }
    }

    public String wrapSourceCodeInContentWorld(ContentWorld contentWorld, String str) {
        return (contentWorld == null || contentWorld.equals(ContentWorld.PAGE)) ? str : CONTENT_WORLD_WRAPPER_JS_SOURCE.replace(PluginScriptsUtil.VAR_CONTENT_WORLD_NAME, escapeContentWorldName(contentWorld.getName())).replace(PluginScriptsUtil.VAR_JSON_SOURCE_ENCODED, escapeCode(str));
    }
}
