package com.pichillilorenzo.flutter_inappwebview.types;

import X.l;
import android.text.TextUtils;
import android.webkit.ValueCallback;
import com.pichillilorenzo.flutter_inappwebview.Util;
import com.pichillilorenzo.flutter_inappwebview.plugin_scripts_js.JavaScriptBridgeJS;
import java.util.ArrayList;
import java.util.List;
/* loaded from: classes.dex */
public class WebMessagePort {
    public String name;
    public WebMessageChannel webMessageChannel;
    public boolean isClosed = false;
    public boolean isTransferred = false;
    public boolean isStarted = false;

    public WebMessagePort(String str, WebMessageChannel webMessageChannel) {
        this.name = str;
        this.webMessageChannel = webMessageChannel;
    }

    public void close(final ValueCallback valueCallback) {
        InAppWebViewInterface inAppWebViewInterface;
        if (this.isTransferred) {
            throw new Exception("Port is already transferred");
        }
        this.isClosed = true;
        WebMessageChannel webMessageChannel = this.webMessageChannel;
        if (webMessageChannel == null || (inAppWebViewInterface = webMessageChannel.webView) == null) {
            inAppWebViewInterface = null;
        }
        if (inAppWebViewInterface == null) {
            valueCallback.onReceiveValue(null);
            return;
        }
        StringBuilder y2 = l.y("(function() {  var webMessageChannel = window.flutter_inappwebview._webMessageChannels['");
        y2.append(this.webMessageChannel.id);
        y2.append("'];  if (webMessageChannel != null) {      webMessageChannel.");
        inAppWebViewInterface.evaluateJavascript(l.w(y2, this.name, ".close();  }})();"), null, new ValueCallback() { // from class: com.pichillilorenzo.flutter_inappwebview.types.WebMessagePort.3
            @Override // android.webkit.ValueCallback
            public void onReceiveValue(String str) {
                valueCallback.onReceiveValue(null);
            }
        });
    }

    public void dispose() {
        this.isClosed = true;
        this.webMessageChannel = null;
    }

    public void postMessage(WebMessage webMessage, final ValueCallback valueCallback) {
        String str;
        if (this.isClosed || this.isTransferred) {
            throw new Exception("Port is already closed or transferred");
        }
        WebMessageChannel webMessageChannel = this.webMessageChannel;
        InAppWebViewInterface inAppWebViewInterface = (webMessageChannel == null || (inAppWebViewInterface = webMessageChannel.webView) == null) ? null : null;
        if (inAppWebViewInterface != null) {
            List<WebMessagePort> list = webMessage.ports;
            if (list != null) {
                ArrayList arrayList = new ArrayList();
                for (WebMessagePort webMessagePort : list) {
                    if (webMessagePort == this) {
                        throw new Exception("Source port cannot be transferred");
                    }
                    if (webMessagePort.isStarted) {
                        throw new Exception("Port is already started");
                    }
                    if (webMessagePort.isClosed || webMessagePort.isTransferred) {
                        throw new Exception("Port is already closed or transferred");
                    }
                    webMessagePort.isTransferred = true;
                    StringBuilder y2 = l.y("window.flutter_inappwebview._webMessageChannels['");
                    y2.append(this.webMessageChannel.id);
                    y2.append("'].");
                    y2.append(webMessagePort.name);
                    arrayList.add(y2.toString());
                }
                StringBuilder y3 = l.y("[");
                y3.append(TextUtils.join(", ", arrayList));
                y3.append("]");
                str = y3.toString();
            } else {
                str = "null";
            }
            String str2 = webMessage.data;
            String replaceAll = str2 != null ? Util.replaceAll(str2, "'", "\\'") : "null";
            StringBuilder y4 = l.y("(function() {  var webMessageChannel = window.flutter_inappwebview._webMessageChannels['");
            y4.append(this.webMessageChannel.id);
            y4.append("'];  if (webMessageChannel != null) {      webMessageChannel.");
            y4.append(this.name);
            y4.append(".postMessage('");
            y4.append(replaceAll);
            y4.append("', ");
            inAppWebViewInterface.evaluateJavascript(l.w(y4, str, ");  }})();"), null, new ValueCallback() { // from class: com.pichillilorenzo.flutter_inappwebview.types.WebMessagePort.2
                @Override // android.webkit.ValueCallback
                public void onReceiveValue(String str3) {
                    valueCallback.onReceiveValue(null);
                }
            });
        } else {
            valueCallback.onReceiveValue(null);
        }
        webMessage.dispose();
    }

    public void setWebMessageCallback(final ValueCallback valueCallback) {
        InAppWebViewInterface inAppWebViewInterface;
        if (this.isClosed || this.isTransferred) {
            throw new Exception("Port is already closed or transferred");
        }
        this.isStarted = true;
        WebMessageChannel webMessageChannel = this.webMessageChannel;
        if (webMessageChannel == null || (inAppWebViewInterface = webMessageChannel.webView) == null) {
            inAppWebViewInterface = null;
        }
        if (inAppWebViewInterface == null) {
            if (valueCallback != null) {
                valueCallback.onReceiveValue(null);
                return;
            }
            return;
        }
        int equals = 1 ^ this.name.equals("port1");
        StringBuilder y2 = l.y("(function() {  var webMessageChannel = window.flutter_inappwebview._webMessageChannels['");
        y2.append(this.webMessageChannel.id);
        y2.append("'];  if (webMessageChannel != null) {      webMessageChannel.");
        y2.append(this.name);
        y2.append(".onmessage = function (event) {          window.");
        y2.append(JavaScriptBridgeJS.JAVASCRIPT_BRIDGE_NAME);
        y2.append(".callHandler('onWebMessagePortMessageReceived', {              'webMessageChannelId': '");
        y2.append(this.webMessageChannel.id);
        y2.append("',              'index': ");
        y2.append(equals);
        y2.append(",              'message': event.data          });      }  }})();");
        inAppWebViewInterface.evaluateJavascript(y2.toString(), null, new ValueCallback() { // from class: com.pichillilorenzo.flutter_inappwebview.types.WebMessagePort.1
            @Override // android.webkit.ValueCallback
            public void onReceiveValue(String str) {
                ValueCallback valueCallback2 = valueCallback;
                if (valueCallback2 != null) {
                    valueCallback2.onReceiveValue(null);
                }
            }
        });
    }
}
